"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const light_my_request_1 = require("light-my-request");
const stream_1 = require("stream");
const url_1 = __importDefault(require("url"));
const axios_core_1 = require("./axios-core");
const axios_error_1 = require("./axios-error");
const axios_helpers_1 = require("./axios-helpers");
const utils = __importStar(require("./axios-utils"));
function createLightMyRequestAdapter(dispatchFunc, options = {}) {
    return function lightMyRequestAdapter(config) {
        return new Promise((resolvePromise, rejectPromise) => {
            let onCanceled;
            function done() {
                if (config.cancelToken) {
                    config.cancelToken.unsubscribe(onCanceled);
                }
                if (config.signal) {
                    config.signal.removeEventListener("abort", onCanceled);
                }
            }
            function resolve(value) {
                done();
                resolvePromise(value);
            }
            function reject(value) {
                done();
                rejectPromise(value);
            }
            const data = config.data;
            const headers = config.headers ?? {};
            const headerNames = {};
            Object.keys(headers).forEach(function storeLowerName(name) {
                headerNames[name.toLowerCase()] = name;
            });
            // support for https://www.npmjs.com/package/form-data api
            if (utils.isFormData(data) && utils.isFunction(data.getHeaders)) {
                Object.assign(headers, data.getHeaders());
            }
            else if (data && !utils.isStream(data)) {
                if (config.maxBodyLength &&
                    config.maxBodyLength > -1 &&
                    data.length > config.maxBodyLength) {
                    return reject(new axios_1.AxiosError("Request body larger than maxBodyLength limit", axios_1.AxiosError.ERR_BAD_REQUEST, config));
                }
            }
            // HTTP basic authentication
            let auth = undefined;
            if (config.auth) {
                const username = config.auth.username || "";
                const password = config.auth.password || "";
                auth = username + ":" + password;
            }
            // Parse url
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            const fullPath = (0, axios_core_1.buildFullPath)(config.baseURL, config.url);
            const parsed = url_1.default.parse(fullPath);
            const protocol = parsed.protocol || "http:";
            if (!auth && parsed.auth) {
                const urlAuth = parsed.auth.split(":");
                const urlUsername = urlAuth[0] || "";
                const urlPassword = urlAuth[1] || "";
                auth = urlUsername + ":" + urlPassword;
            }
            if (auth) {
                if (headerNames.authorization) {
                    delete headers[headerNames.authorization];
                }
                headers.authorization = "Basic " + Buffer.from(auth).toString("base64");
            }
            let query;
            try {
                query = (0, axios_helpers_1.buildParams)(config.params, config.paramsSerializer).replace(/^\?/, "");
            }
            catch (err) {
                const customErr = new Error(err.message);
                customErr.config = config;
                customErr.url = config.url;
                customErr.exists = true;
                reject(customErr);
                return;
            }
            if (config.socketPath) {
                reject(new Error("socketPath not supported"));
                return;
            }
            if (config.proxy != null) {
                reject(new Error("proxy not supported"));
                return;
            }
            let aborted = false;
            (0, light_my_request_1.inject)(dispatchFunc, {
                url: {
                    pathname: parsed.path ?? "",
                    protocol: protocol,
                    hostname: parsed.hostname ?? undefined,
                    port: parsed.port ?? undefined,
                    query,
                },
                method: config.method?.toUpperCase(),
                headers: headers,
                payload: config.data,
                server: options.server,
                remoteAddress: options.remoteAddress,
            }, (err, res) => {
                if (aborted)
                    return;
                if (err) {
                    reject((0, axios_error_1.axiosErrorFrom)(err, null, config, res.raw.req));
                }
                const response = {
                    status: res.statusCode,
                    statusText: res.statusMessage,
                    headers: res.headers,
                    config: config,
                    request: res.raw.req,
                    data: undefined,
                };
                if (config.responseType === "stream") {
                    const responseData = new stream_1.Readable();
                    responseData.push(res.body);
                    responseData.push(null);
                    response.data = responseData;
                    (0, axios_core_1.settle)(resolve, reject, response);
                }
                else {
                    try {
                        if (config.responseType === "arraybuffer") {
                            response.data = Buffer.from(res.body);
                        }
                        else {
                            let responseData = res.body;
                            if (!config.responseEncoding ||
                                config.responseEncoding === "utf8") {
                                responseData = utils.stripBOM(responseData);
                            }
                            response.data = responseData;
                        }
                    }
                    catch (err) {
                        reject((0, axios_error_1.axiosErrorFrom)(err, null, config, response.request, response));
                    }
                    (0, axios_core_1.settle)(resolve, reject, response);
                }
            });
            if (config.cancelToken || config.signal) {
                // Handle cancellation
                onCanceled = function (cancel) {
                    if (aborted)
                        return;
                    aborted = true;
                    reject(!cancel || (cancel && cancel.type) ? new axios_1.CanceledError() : cancel);
                };
                config.cancelToken &&
                    config.cancelToken.subscribe(onCanceled);
                if (config.signal) {
                    config.signal.aborted
                        ? onCanceled()
                        : config.signal.addEventListener("abort", onCanceled);
                }
            }
        });
    };
}
exports.default = createLightMyRequestAdapter;
//# sourceMappingURL=index.js.map